@@ -491,6 +491,8 @@ class CoarseTransformer(nn.Module):
         **kwargs
     ):
         super().__init__()
+        self.num_semantic_tokens = num_semantic_tokens
+
         self.has_condition = has_condition
         self.embed_text = partial(t5_encode_text, name = t5_name)
         self.cond_drop_prob = cond_drop_prob
@@ -826,7 +828,7 @@ class SemanticTransformerWrapper(nn.Module):
         super().__init__()
         self.wav2vec = wav2vec
         self.transformer = transformer
-        assert self.wav2vec.codebook_size == transformer.num_semantic_tokens, f'num_semantic_tokens on SemanticTransformer must be set to {self.wav2vec.codebook_size}'
+        assert not exists(self.wav2vec) or self.wav2vec.codebook_size == transformer.num_semantic_tokens, f'num_semantic_tokens on SemanticTransformer must be set to {self.wav2vec.codebook_size}'
 
         self.unique_consecutive = unique_consecutive
         self.pad_id = pad_id
@@ -1378,6 +1380,10 @@ class AudioLM(nn.Module):
     ):
         super().__init__()
 
+        assert semantic_transformer.num_semantic_tokens == coarse_transformer.num_semantic_tokens
+        assert coarse_transformer.codebook_size == fine_transformer.codebook_size
+        assert coarse_transformer.num_coarse_quantizers == fine_transformer.num_coarse_quantizers
+
         self.semantic = SemanticTransformerWrapper(
             wav2vec = wav2vec,
             transformer = semantic_transformer,
